@@ -29,6 +29,9 @@ from .harris.rent_relief_act.rent_relief_tax_credit import (
 from .congress.tlaib import (
     create_end_child_poverty_act_reform,
 )
+from .congress.tlaib.economic_dignity_for_all_agenda import (
+    create_end_child_poverty_act_reform as create_edaa_end_child_poverty_act_reform,
+)
 from .congress.tlaib.boost import (
     create_boost_middle_class_tax_credit_reform,
 )
@@ -108,6 +111,10 @@ from .crfb import (
     create_non_refundable_ss_credit_reform,
     create_senior_deduction_extension_reform,
 )
+from .states.ri.ctc.ri_ctc_reform import create_ri_ctc_reform
+from .states.ri.exemption.ri_exemption_reform import (
+    create_ri_exemption_reform_fn,
+)
 from .aca import (
     create_aca_ptc_additional_bracket_reform,
     create_aca_ptc_simplified_bracket_reform,
@@ -164,6 +171,9 @@ def create_structural_reforms_from_parameters(parameters, period):
     end_child_poverty_act = create_end_child_poverty_act_reform(
         parameters, period
     )
+    edaa_end_child_poverty_act = create_edaa_end_child_poverty_act_reform(
+        parameters, period
+    )
     boost_middle_class_tax_credit = (
         create_boost_middle_class_tax_credit_reform(parameters, period)
     )
@@ -252,6 +262,8 @@ def create_structural_reforms_from_parameters(parameters, period):
     ctc_minimum_refundable_amount = (
         create_ctc_minimum_refundable_amount_reform(parameters, period)
     )
+    ri_ctc = create_ri_ctc_reform(parameters, period)
+    ri_exemption = create_ri_exemption_reform_fn(parameters, period)
     aca_ptc_additional_bracket = create_aca_ptc_additional_bracket_reform(
         parameters, period
     )
@@ -277,6 +289,7 @@ def create_structural_reforms_from_parameters(parameters, period):
         middle_class_tax_credit,
         rent_relief_tax_credit,
         end_child_poverty_act,
+        edaa_end_child_poverty_act,
         boost_middle_class_tax_credit,
         mn_walz_hf1938,
         or_rebate_state_tax_exempt,
@@ -308,6 +321,8 @@ def create_structural_reforms_from_parameters(parameters, period):
         ctc_per_child_phase_out,
         ctc_per_child_phase_in,
         ctc_minimum_refundable_amount,
+        ri_ctc,
+        ri_exemption,
         aca_ptc_additional_bracket,
         aca_ptc_simplified_bracket,
     ]
