@@ -13,7 +13,9 @@ class aca_ptc(Variable):
     def formula(tax_unit, period, parameters):
         plan_cost = tax_unit("slcsp", period)
         income = tax_unit("aca_magi", period)
-        applicable_figure = tax_unit("aca_ptc_phase_out_rate", period)
+        applicable_figure = tax_unit(
+            "aca_required_contribution_percentage", period
+        )
         takes_up_aca_if_eligible = tax_unit("takes_up_aca_if_eligible", period)
         return (
             max_(0, plan_cost - income * applicable_figure)
