@@ -19,7 +19,7 @@ class mt_standard_deduction_joint(Variable):
 
         if p.state_specific_deduction_applies:
             # ── Pre-2024 MT-specific calculation ───────────────────────────────
-            agi = add(person.tax_unit, period, ["mt_agi"])
+            agi = add(person.tax_unit, period, ["mt_agi_indiv"])
             floor = p.floor[filing_status]
             cap = p.cap[filing_status]
             uncapped = p.rate * agi
