@@ -19,8 +19,8 @@ class nj_cdcc(Variable):
         taxable_income = tax_unit("nj_taxable_income", period)
 
         # Get federal CDCC
-        # New Jersey matches the potential federal credit
-        federal_cdcc = tax_unit("cdcc_potential", period)
+        # New Jersey matches the actual federal credit value
+        federal_cdcc = tax_unit("cdcc", period)
 
         # Calculate NJ CDCC
         rate = p.calc(taxable_income, right=True)
