@@ -13,7 +13,9 @@ class meets_snap_general_work_requirements(Variable):
     def formula(person, period, parameters):
         p = parameters(period).gov.usda.snap.work_requirements.general
         age = person("monthly_age", period)
-        weekly_hours_worked = person("weekly_hours_worked", period.this_year)
+        weekly_hours_worked = person(
+            "weekly_hours_worked_before_lsr", period.this_year
+        )
         # Under 16 or 60 years of age or older are exempted
         worked_exempted_age = p.age_threshold.exempted.calc(age)
         # Unable to work due to a physical or mental limitation
