@@ -14,7 +14,7 @@ class snap_self_employment_expense_deduction(Variable):
 
     def formula(spm_unit, period, parameters):
         self_employment_income = add(
-            spm_unit, period, ["self_employment_income"]
+            spm_unit, period, ["self_employment_income_before_lsr"]
         )
         expenses = spm_unit("snap_self_employment_income_expense", period)
         p = parameters(period).gov.usda.snap.income.deductions.self_employment
